@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2004 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2004 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +24,8 @@
 //
 
 COSXServerTaskBarReceiver::COSXServerTaskBarReceiver(
-				const CBufferedLogOutputter*)
+		const CBufferedLogOutputter*, IEventQueue* events) :
+    CServerTaskBarReceiver(events)
 {
 	// add ourself to the task bar
 	ARCH->addReceiver(this);
@@ -59,7 +61,7 @@ COSXServerTaskBarReceiver::getIcon() const
 }
 
 IArchTaskBarReceiver*
-createTaskBarReceiver(const CBufferedLogOutputter* logBuffer)
+createTaskBarReceiver(const CBufferedLogOutputter* logBuffer, IEventQueue* events)
 {
-	return new COSXServerTaskBarReceiver(logBuffer);
+	return new COSXServerTaskBarReceiver(logBuffer, events);
 }
