@@ -88,8 +88,9 @@ class MainWindow : public QMainWindow, public Ui::MainWindowBase
 		QString configFilename();
 		QString address();
 		QString appPath(const QString& name);
-		void start(bool firstRun);
+		void start();
 		void clearLog();
+		VersionChecker& versionChecker() { return m_VersionChecker; }
 
 	public slots:
 		void appendLogRaw(const QString& text);
@@ -113,7 +114,6 @@ class MainWindow : public QMainWindow, public Ui::MainWindowBase
 		void logOutput();
 		void logError();
 		void updateFound(const QString& version);
-		void refreshApplyButton();
 
 	protected:
 		QSettings& settings() { return m_Settings; }
@@ -140,7 +140,9 @@ class MainWindow : public QMainWindow, public Ui::MainWindowBase
 		QString getScreenName();
 		void stopService();
 		void stopDesktop();
-		void setFormEnabled(bool enabled);
+		void changeEvent(QEvent* event);
+		void retranslateMenuBar();
+		void updatePremiumInfo();
 
 	private:
 		QSettings& m_Settings;
@@ -151,12 +153,16 @@ class MainWindow : public QMainWindow, public Ui::MainWindowBase
 		QTemporaryFile* m_pTempConfigFile;
 		QSystemTrayIcon* m_pTrayIcon;
 		QMenu* m_pTrayIconMenu;
-		bool m_alreadyHidden;
-		VersionChecker m_versionChecker;
-		SetupWizard* m_SetupWizard;
+		bool m_AlreadyHidden;
+		VersionChecker m_VersionChecker;
 		IpcClient m_IpcClient;
 		bool m_ElevateProcess;
 		bool m_SuppressElevateWarning;
+		QMenuBar* m_pMenuBar;
+		QMenu* m_pMenuFile;
+		QMenu* m_pMenuEdit;
+		QMenu* m_pMenuWindow;
+		QMenu* m_pMenuHelp;
 
 private slots:
 	void on_m_pButtonApply_clicked();
