@@ -28,9 +28,19 @@ class QSynergyApplication : public QApplication
 {
 	public:
 		QSynergyApplication(int& argc, char** argv);
+		~QSynergyApplication();
 
 	public:
 		void commitData(QSessionManager& manager);
+		void switchTranslator(QString lang);
+		void setTranslator(QTranslator* translator);
+
+		static QSynergyApplication* getInstance();
+
+	private:
+		QTranslator* m_Translator;
+
+		static QSynergyApplication* s_Instance;
 };
 
 #endif
