@@ -17,11 +17,14 @@
 
 #pragma once
 
-#include <QWizard>
 #include "ui_SetupWizardBase.h"
-#include "CryptoMode.h"
+#include "SynergyLocale.h"
+
+#include <QWizard>
+#include <QNetworkAccessManager>
 
 class MainWindow;
+class QMessageBox;
 
 class SetupWizard : public QWizard, public Ui::SetupWizardBase
 {
@@ -30,12 +33,22 @@ public:
 	SetupWizard(MainWindow& mainWindow, bool startMain);
 	virtual ~SetupWizard();
 	bool validateCurrentPage();
-protected slots:
-	void handleFinished();
+
+protected:
+	void changeEvent(QEvent* event);
+	void accept();
+	void reject();
+
+private:
+	bool isPremiumLoginValid(QMessageBox& message);
+
 private:
 	MainWindow& m_MainWindow;
 	bool m_StartMain;
-	CryptoMode parseCryptoMode(const QString& s);
+	SynergyLocale m_Locale;
+
 private slots:
-    void on_m_pComboCryptoMode_currentIndexChanged(int index);
+	void on_m_pCheckBoxEnableCrypto_stateChanged(int );
+	void on_m_pComboLanguage_currentIndexChanged(int index);
+	void on_m_pRadioButtonPremiumLogin_toggled(bool checked);
 };
