@@ -27,6 +27,11 @@
 #include <QtCore>
 #include <QtGui>
 #include <QSettings>
+#include <QMessageBox>
+
+#if defined(Q_OS_MAC)
+#include <Carbon/Carbon.h>
+#endif
 
 class QThreadImpl : public QThread
 {
@@ -39,6 +44,10 @@ public:
 
 int waitForTray();
 
+#if defined(Q_OS_MAC)
+bool checkMacAssistiveDevices();
+#endif
+
 int main(int argc, char* argv[])
 {
 	QCoreApplication::setOrganizationName("Synergy");
@@ -47,22 +56,35 @@ int main(int argc, char* argv[])
 
 	QSynergyApplication app(argc, argv);
 
+#if defined(Q_OS_MAC)
+
+	if (app.applicationDirPath().startsWith("/Volumes/")) {
+		QMessageBox::information(
+			NULL, "Synergy",
+			"Please drag Synergy to the Applications folder, and open it from there.");
+		return 1;
+	}
+	
+	if (!checkMacAssistiveDevices())
+	{
+		return 1;
+	}
+#endif
+
 	if (!waitForTray())
+	{
 		return -1;
+	}
 
+#ifndef Q_OS_WIN
 	QApplication::setQuitOnLastWindowClosed(false);
-
-	QTranslator qtTranslator;
-	qtTranslator.load("qt_" + QLocale::system().name(),
-		QLibraryInfo::location(QLibraryInfo::TranslationsPath));
-	app.installTranslator(&qtTranslator);
-
-	QTranslator synergyTranslator;
-	synergyTranslator.load("res/lang/" + QLocale::system().name());
-	app.installTranslator(&synergyTranslator);
+#endif
 
 	QSettings settings;
 	AppConfig appConfig(&settings);
+
+	app.switchTranslator(appConfig.language());
+
 	MainWindow mainWindow(settings, appConfig);
 	SetupWizard setupWizard(mainWindow, true);
 
@@ -72,7 +94,7 @@ int main(int argc, char* argv[])
 	}
 	else
 	{
-		mainWindow.start(false);
+		mainWindow.start();
 	}
 
 	return app.exec();
@@ -102,3 +124,38 @@ int waitForTray()
 	return true;
 }
 
+#if defined(Q_OS_MAC)
+bool checkMacAssistiveDevices()
+{
+#if __MAC_OS_X_VERSION_MIN_REQUIRED >= 1090 // mavericks
+
+	// new in mavericks, applications are trusted individually
+	// with use of the accessibility api. this call will show a
+	// prompt which can show the security/privacy/accessibility
+	// tab, with a list of allowed applications. synergy should
+	// show up there automatically, but will be unchecked.
+
+	const void* keys[] = { kAXTrustedCheckOptionPrompt };
+	const void* values[] = { kCFBooleanTrue };
+
+	CFDictionaryRef options = CFDictionaryCreate(NULL, keys, values, 1, NULL, NULL);
+	bool result = AXIsProcessTrustedWithOptions(options);
+	CFRelease(options);
+
+	return result;
+
+#else
+
+	// now deprecated in mavericks.
+	bool result = AXAPIEnabled();
+	if (!result) {
+		QMessageBox::information(
+			NULL, "Synergy",
+			"Please enable access to assistive devices "
+			"(System Preferences), then re-open Synergy.");
+	}
+	return result;
+
+#endif
+}
+#endif
