@@ -23,8 +23,6 @@
 #include "CEvent.h"
 #include "CString.h"
 
-#define EVENTQUEUE IEventQueue::getInstance()
-
 class IEventJob;
 class IEventQueueBuffer;
 
@@ -32,6 +30,26 @@ class IEventQueueBuffer;
 // IEventQueueBuffer.
 class CEventQueueTimer;
 
+// Event type registration classes.
+class CClientEvents;
+class IStreamEvents;
+class CIpcClientEvents;
+class CIpcClientProxyEvents;
+class CIpcServerEvents;
+class CIpcServerProxyEvents;
+class IDataSocketEvents;
+class IListenSocketEvents;
+class ISocketEvents;
+class COSXScreenEvents;
+class CClientListenerEvents;
+class CClientProxyEvents;
+class CClientProxyUnknownEvents;
+class CServerEvents;
+class CServerAppEvents;
+class IKeyStateEvents;
+class IPrimaryScreenEvents;
+class IScreenEvents;
+
 //! Event queue interface
 /*!
 An event queue provides a queue of CEvents.  Clients can block waiting
@@ -149,13 +167,6 @@ public:
 	*/
 	virtual void		removeHandlers(void* target) = 0;
 
-	//! Creates a new event type
-	/*!
-	Returns a unique event type id.
-	*/
-	virtual CEvent::Type
-						registerType(const char* name) = 0;
-
 	//! Creates a new event type
 	/*!
 	If \p type contains \c kUnknown then it is set to a unique event
@@ -201,30 +212,32 @@ public:
 	/*!
 	Returns the target to use for dispatching \c CEvent::kSystem events.
 	*/
-	static void*		getSystemTarget();
-
-	//! Get the singleton instance
-	/*!
-	Returns the singleton instance of the event queue
-	*/
-	static IEventQueue*	getInstance();
+	virtual void*		getSystemTarget() = 0;
 
 	//@}
+	
+	//
+	// Event type providers.
+	//
 
-protected:
-	//! @name manipulators
-	//@{
-
-	//! Set the singleton instance
-	/*!
-	Sets the singleton instance of the event queue
-	*/
-	static void			setInstance(IEventQueue*);
-
-	//@}
-
-private:
-	static IEventQueue*	s_instance;
+	virtual CClientEvents&				forCClient() = 0;
+	virtual IStreamEvents&				forIStream() = 0;
+	virtual CIpcClientEvents&			forCIpcClient() = 0;
+	virtual CIpcClientProxyEvents&		forCIpcClientProxy() = 0;
+	virtual CIpcServerEvents&			forCIpcServer() = 0;
+	virtual CIpcServerProxyEvents&		forCIpcServerProxy() = 0;
+	virtual IDataSocketEvents&			forIDataSocket() = 0;
+	virtual IListenSocketEvents&		forIListenSocket() = 0;
+	virtual ISocketEvents&				forISocket() = 0;
+	virtual COSXScreenEvents&			forCOSXScreen() = 0;
+	virtual CClientListenerEvents&		forCClientListener() = 0;
+	virtual CClientProxyEvents&			forCClientProxy() = 0;
+	virtual CClientProxyUnknownEvents&	forCClientProxyUnknown() = 0;
+	virtual CServerEvents&				forCServer() = 0;
+	virtual CServerAppEvents&			forCServerApp() = 0;
+	virtual IKeyStateEvents&			forIKeyState() = 0;
+	virtual IPrimaryScreenEvents&		forIPrimaryScreen() = 0;
+	virtual IScreenEvents&				forIScreen() = 0;
 };
 
 #endif
