@@ -30,26 +30,29 @@
 #include "CLog.h"
 #include "IEventQueue.h"
 #include "TMethodEventJob.h"
-#include <cstring>
-#include <cstdlib>
 #include "CArch.h"
 #include "IPlatformScreen.h"
 #include "CCryptoStream.h"
+#include "CThread.h"
+#include "TMethodJob.h"
+#include "CFileChunker.h"
+#include <cstring>
+#include <cstdlib>
+#include <sstream>
+#include <fstream>
+#include <stdexcept>
 
 //
 // CClient
 //
 
-CEvent::Type			CClient::s_connectedEvent        = CEvent::kUnknown;
-CEvent::Type			CClient::s_connectionFailedEvent = CEvent::kUnknown;
-CEvent::Type			CClient::s_disconnectedEvent     = CEvent::kUnknown;
-
-CClient::CClient(IEventQueue* eventQueue,
+CClient::CClient(IEventQueue* events,
 				const CString& name, const CNetworkAddress& address,
 				ISocketFactory* socketFactory,
 				IStreamFilterFactory* streamFilterFactory,
 				CScreen* screen,
-				const CCryptoOptions& crypto) :
+				const CCryptoOptions& crypto,
+				bool enableDragDrop) :
 	m_mock(false),
 	m_name(name),
 	m_serverAddress(address),
@@ -63,30 +66,36 @@ CClient::CClient(IEventQueue* eventQueue,
 	m_active(false),
 	m_suspended(false),
 	m_connectOnResume(false),
-	m_eventQueue(eventQueue),
+	m_events(events),
 	m_cryptoStream(NULL),
-	m_crypto(crypto)
+	m_crypto(crypto),
+	m_sendFileThread(NULL),
+	m_writeToDropDirThread(NULL),
+	m_enableDragDrop(enableDragDrop)
 {
 	assert(m_socketFactory != NULL);
 	assert(m_screen        != NULL);
 
 	// register suspend/resume event handlers
-	m_eventQueue->adoptHandler(IScreen::getSuspendEvent(),
+	m_events->adoptHandler(m_events->forIScreen().suspend(),
 							getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleSuspend));
-	m_eventQueue->adoptHandler(IScreen::getResumeEvent(),
+	m_events->adoptHandler(m_events->forIScreen().resume(),
 							getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleResume));
-	m_eventQueue->adoptHandler(IPlatformScreen::getGameDeviceTimingRespEvent(),
-							getEventTarget(),
-							new TMethodEventJob<CClient>(this,
-								&CClient::handleGameDeviceTimingResp));
-	m_eventQueue->adoptHandler(IPlatformScreen::getGameDeviceFeedbackEvent(),
-							getEventTarget(),
-							new TMethodEventJob<CClient>(this,
-								&CClient::handleGameDeviceFeedback));
+
+	if (m_enableDragDrop) {
+		m_events->adoptHandler(m_events->forIScreen().fileChunkSending(),
+								this,
+								new TMethodEventJob<CClient>(this,
+									&CClient::handleFileChunkSending));
+		m_events->adoptHandler(m_events->forIScreen().fileRecieveCompleted(),
+								this,
+								new TMethodEventJob<CClient>(this,
+									&CClient::handleFileRecieveCompleted));
+	}
 }
 
 CClient::~CClient()
@@ -95,9 +104,9 @@ CClient::~CClient()
 		return;
 	}
 
-	m_eventQueue->removeHandler(IScreen::getSuspendEvent(),
+	m_events->removeHandler(m_events->forIScreen().suspend(),
 							  getEventTarget());
-	m_eventQueue->removeHandler(IScreen::getResumeEvent(),
+	m_events->removeHandler(m_events->forIScreen().resume(),
 							  getEventTarget());
 
 	cleanupTimer();
@@ -144,11 +153,11 @@ CClient::connect()
 		if (m_streamFilterFactory != NULL) {
 			m_stream = m_streamFilterFactory->create(m_stream, true);
 		}
-		m_stream = new CPacketStreamFilter(m_stream, true);
+		m_stream = new CPacketStreamFilter(m_events, m_stream, true);
 
 		if (m_crypto.m_mode != kDisabled) {
 			m_cryptoStream = new CCryptoStream(
-				EVENTQUEUE, m_stream, m_crypto, true);
+				m_events, m_stream, m_crypto, true);
 			m_stream = m_cryptoStream;
 		}
 
@@ -181,7 +190,7 @@ CClient::disconnect(const char* msg)
 		sendConnectionFailedEvent(msg);
 	}
 	else {
-		sendEvent(getDisconnectedEvent(), NULL);
+		sendEvent(m_events->forCClient().disconnected(), NULL);
 	}
 }
 
@@ -190,7 +199,7 @@ CClient::handshakeComplete()
 {
 	m_ready = true;
 	m_screen->enable();
-	sendEvent(getConnectedEvent(), NULL);
+	sendEvent(m_events->forCClient().connected(), NULL);
 }
 
 void
@@ -219,27 +228,6 @@ CClient::getServerAddress() const
 	return m_serverAddress;
 }
 
-CEvent::Type
-CClient::getConnectedEvent()
-{
-	return EVENTQUEUE->registerTypeOnce(s_connectedEvent,
-							"CClient::connected");
-}
-
-CEvent::Type
-CClient::getConnectionFailedEvent()
-{
-	return EVENTQUEUE->registerTypeOnce(s_connectionFailedEvent,
-							"CClient::failed");
-}
-
-CEvent::Type
-CClient::getDisconnectedEvent()
-{
-	return EVENTQUEUE->registerTypeOnce(s_disconnectedEvent,
-							"CClient::disconnected");
-}
-
 void*
 CClient::getEventTarget() const
 {
@@ -378,30 +366,6 @@ CClient::setOptions(const COptionsList& options)
 	m_screen->setOptions(options);
 }
 
-void
-CClient::gameDeviceButtons(GameDeviceID id, GameDeviceButton buttons)
-{
-	m_screen->gameDeviceButtons(id, buttons);
-}
-
-void
-CClient::gameDeviceSticks(GameDeviceID id, SInt16 x1, SInt16 y1, SInt16 x2, SInt16 y2)
-{
-	m_screen->gameDeviceSticks(id, x1, y1, x2, y2);
-}
-
-void
-CClient::gameDeviceTriggers(GameDeviceID id, UInt8 t1, UInt8 t2)
-{
-	m_screen->gameDeviceTriggers(id, t1, t2);
-}
-
-void
-CClient::gameDeviceTimingReq()
-{
-	m_screen->gameDeviceTimingReq();
-}
-
 CString
 CClient::getName() const
 {
@@ -446,7 +410,7 @@ CClient::sendClipboard(ClipboardID id)
 void
 CClient::sendEvent(CEvent::Type type, void* data)
 {
-	m_eventQueue->addEvent(CEvent(type, getEventTarget(), data));
+	m_events->addEvent(CEvent(type, getEventTarget(), data));
 }
 
 void
@@ -454,8 +418,19 @@ CClient::sendConnectionFailedEvent(const char* msg)
 {
 	CFailInfo* info = new CFailInfo(msg);
 	info->m_retry = true;
-	CEvent event(getConnectionFailedEvent(), getEventTarget(), info, CEvent::kDontFreeData);
-	m_eventQueue->addEvent(event);
+	CEvent event(m_events->forCClient().connectionFailed(), getEventTarget(), info, CEvent::kDontFreeData);
+	m_events->addEvent(event);
+}
+
+void
+CClient::sendFileChunk(const void* data)
+{
+	CFileChunker::CFileChunk* fileChunk = reinterpret_cast<CFileChunker::CFileChunk*>(const_cast<void*>(data));
+	LOG((CLOG_DEBUG1 "sendFileChunk"));
+	assert(m_server != NULL);
+
+	// relay
+	m_server->fileChunkSending(fileChunk->m_chunk[0], &(fileChunk->m_chunk[1]), fileChunk->m_dataSize);
 }
 
 void
@@ -463,11 +438,11 @@ CClient::setupConnecting()
 {
 	assert(m_stream != NULL);
 
-	m_eventQueue->adoptHandler(IDataSocket::getConnectedEvent(),
+	m_events->adoptHandler(m_events->forIDataSocket().connected(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleConnected));
-	m_eventQueue->adoptHandler(IDataSocket::getConnectionFailedEvent(),
+	m_events->adoptHandler(m_events->forIDataSocket().connectionFailed(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleConnectionFailed));
@@ -478,23 +453,23 @@ CClient::setupConnection()
 {
 	assert(m_stream != NULL);
 
-	m_eventQueue->adoptHandler(ISocket::getDisconnectedEvent(),
+	m_events->adoptHandler(m_events->forISocket().disconnected(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleDisconnected));
-	m_eventQueue->adoptHandler(m_stream->getInputReadyEvent(),
+	m_events->adoptHandler(m_events->forIStream().inputReady(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleHello));
-	m_eventQueue->adoptHandler(m_stream->getOutputErrorEvent(),
+	m_events->adoptHandler(m_events->forIStream().outputError(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleOutputError));
-	m_eventQueue->adoptHandler(m_stream->getInputShutdownEvent(),
+	m_events->adoptHandler(m_events->forIStream().inputShutdown(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleDisconnected));
-	m_eventQueue->adoptHandler(m_stream->getOutputShutdownEvent(),
+	m_events->adoptHandler(m_events->forIStream().outputShutdown(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleDisconnected));
@@ -506,12 +481,12 @@ CClient::setupScreen()
 	assert(m_server == NULL);
 
 	m_ready  = false;
-	m_server = new CServerProxy(this, m_stream, m_eventQueue);
-	m_eventQueue->adoptHandler(IScreen::getShapeChangedEvent(),
+	m_server = new CServerProxy(this, m_stream, m_events);
+	m_events->adoptHandler(m_events->forIScreen().shapeChanged(),
 							getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleShapeChanged));
-	m_eventQueue->adoptHandler(IScreen::getClipboardGrabbedEvent(),
+	m_events->adoptHandler(m_events->forIScreen().clipboardGrabbed(),
 							getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleClipboardGrabbed));
@@ -522,8 +497,8 @@ CClient::setupTimer()
 {
 	assert(m_timer == NULL);
 
-	m_timer = m_eventQueue->newOneShotTimer(15.0, NULL);
-	m_eventQueue->adoptHandler(CEvent::kTimer, m_timer,
+	m_timer = m_events->newOneShotTimer(15.0, NULL);
+	m_events->adoptHandler(CEvent::kTimer, m_timer,
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleConnectTimeout));
 }
@@ -532,9 +507,9 @@ void
 CClient::cleanupConnecting()
 {
 	if (m_stream != NULL) {
-		m_eventQueue->removeHandler(IDataSocket::getConnectedEvent(),
+		m_events->removeHandler(m_events->forIDataSocket().connected(),
 							m_stream->getEventTarget());
-		m_eventQueue->removeHandler(IDataSocket::getConnectionFailedEvent(),
+		m_events->removeHandler(m_events->forIDataSocket().connectionFailed(),
 							m_stream->getEventTarget());
 	}
 }
@@ -543,15 +518,15 @@ void
 CClient::cleanupConnection()
 {
 	if (m_stream != NULL) {
-		m_eventQueue->removeHandler(m_stream->getInputReadyEvent(),
+		m_events->removeHandler(m_events->forIStream().inputReady(),
 							m_stream->getEventTarget());
-		m_eventQueue->removeHandler(m_stream->getOutputErrorEvent(),
+		m_events->removeHandler(m_events->forIStream().outputError(),
 							m_stream->getEventTarget());
-		m_eventQueue->removeHandler(m_stream->getInputShutdownEvent(),
+		m_events->removeHandler(m_events->forIStream().inputShutdown(),
 							m_stream->getEventTarget());
-		m_eventQueue->removeHandler(m_stream->getOutputShutdownEvent(),
+		m_events->removeHandler(m_events->forIStream().outputShutdown(),
 							m_stream->getEventTarget());
-		m_eventQueue->removeHandler(ISocket::getDisconnectedEvent(),
+		m_events->removeHandler(m_events->forISocket().disconnected(),
 							m_stream->getEventTarget());
 		delete m_stream;
 		m_stream = NULL;
@@ -566,9 +541,9 @@ CClient::cleanupScreen()
 			m_screen->disable();
 			m_ready = false;
 		}
-		m_eventQueue->removeHandler(IScreen::getShapeChangedEvent(),
+		m_events->removeHandler(m_events->forIScreen().shapeChanged(),
 							getEventTarget());
-		m_eventQueue->removeHandler(IScreen::getClipboardGrabbedEvent(),
+		m_events->removeHandler(m_events->forIScreen().clipboardGrabbed(),
 							getEventTarget());
 		delete m_server;
 		m_server = NULL;
@@ -579,8 +554,8 @@ void
 CClient::cleanupTimer()
 {
 	if (m_timer != NULL) {
-		m_eventQueue->removeHandler(CEvent::kTimer, m_timer);
-		m_eventQueue->deleteTimer(m_timer);
+		m_events->removeHandler(CEvent::kTimer, m_timer);
+		m_events->deleteTimer(m_timer);
 		m_timer = NULL;
 	}
 }
@@ -634,7 +609,7 @@ CClient::handleOutputError(const CEvent&, void*)
 	cleanupScreen();
 	cleanupConnection();
 	LOG((CLOG_WARN "error sending to server"));
-	sendEvent(getDisconnectedEvent(), NULL);
+	sendEvent(m_events->forCClient().disconnected(), NULL);
 }
 
 void
@@ -644,7 +619,7 @@ CClient::handleDisconnected(const CEvent&, void*)
 	cleanupScreen();
 	cleanupConnection();
 	LOG((CLOG_DEBUG1 "disconnected"));
-	sendEvent(getDisconnectedEvent(), NULL);
+	sendEvent(m_events->forCClient().disconnected(), NULL);
 }
 
 void
@@ -710,7 +685,7 @@ CClient::handleHello(const CEvent&, void*)
 	// receive another event for already pending messages so we fake
 	// one.
 	if (m_stream->isReady()) {
-		m_eventQueue->addEvent(CEvent(m_stream->getInputReadyEvent(),
+		m_events->addEvent(CEvent(m_events->forIStream().inputReady(),
 							m_stream->getEventTarget()));
 	}
 }
@@ -737,19 +712,142 @@ CClient::handleResume(const CEvent&, void*)
 }
 
 void
-CClient::handleGameDeviceTimingResp(const CEvent& event, void*)
+CClient::handleFileChunkSending(const CEvent& event, void*)
 {
-	IPlatformScreen::CGameDeviceTimingRespInfo* info =
-		reinterpret_cast<IPlatformScreen::CGameDeviceTimingRespInfo*>(event.getData());
-
-	m_server->onGameDeviceTimingResp(info->m_freq);
+	sendFileChunk(event.getData());
 }
 
 void
-CClient::handleGameDeviceFeedback(const CEvent& event, void*)
+CClient::handleFileRecieveCompleted(const CEvent& event, void*)
 {
-	IPlatformScreen::CGameDeviceFeedbackInfo* info =
-		reinterpret_cast<IPlatformScreen::CGameDeviceFeedbackInfo*>(event.getData());
+	onFileRecieveCompleted();
+}
 
-	m_server->onGameDeviceFeedback(info->m_id, info->m_m1, info->m_m2);
+void
+CClient::onFileRecieveCompleted()
+{
+	if (isReceivedFileSizeValid()) {
+		m_writeToDropDirThread = new CThread(
+									   new TMethodJob<CClient>(
+															   this, &CClient::writeToDropDirThread));
+	}
+}
+
+
+void
+CClient::writeToDropDirThread(void*)
+{
+	LOG((CLOG_DEBUG "starting write to drop dir thread"));
+
+	while (m_screen->getFakeDraggingStarted()) {
+		ARCH->sleep(.1f);
+	}
+	
+	m_fileTransferDes = m_screen->getDropTarget();
+	LOG((CLOG_DEBUG "dropping file, files=%i target=%s", m_dragFileList.size(), m_fileTransferDes.c_str()));
+
+	if (!m_fileTransferDes.empty() && m_dragFileList.size() > 0) {
+		std::fstream file;
+		CString dropTarget = m_fileTransferDes;
+#ifdef SYSAPI_WIN32
+		dropTarget.append("\\");
+#else
+		dropTarget.append("/");
+#endif
+		dropTarget.append(m_dragFileList.at(0));
+		file.open(dropTarget.c_str(), std::ios::out | std::ios::binary);
+		if (!file.is_open()) {
+			// TODO: file open failed
+		}
+		
+		file.write(m_receivedFileData.c_str(), m_receivedFileData.size());
+		file.close();
+	}
+	else {
+		LOG((CLOG_ERR "drop file failed: drop target is empty"));
+	}
+}
+
+void
+CClient::clearReceivedFileData()
+{
+	m_receivedFileData.clear();
+}
+
+void
+CClient::setExpectedFileSize(CString data)
+{
+	std::istringstream iss(data);
+	iss >> m_expectedFileSize;
+}
+
+void
+CClient::fileChunkReceived(CString data)
+{
+	m_receivedFileData += data;
+}
+
+void
+CClient::dragInfoReceived(UInt32 fileNum, CString data)
+{
+	// TODO: fix duplicate function from CServer
+
+	if (!m_enableDragDrop) {
+		LOG((CLOG_DEBUG "drag drop not enabled, ignoring drag info."));
+		return;
+	}
+
+	CDragInformation::parseDragInfo(m_dragFileList, fileNum, data);
+	LOG((CLOG_DEBUG "drag info received, total drag file number: %i", m_dragFileList.size()));
+
+	for (int i = 0; i < m_dragFileList.size(); ++i) {
+		LOG((CLOG_DEBUG2 "dragging file %i name: %s", i + 1, m_dragFileList.at(i).c_str()));
+	}
+	
+	if (m_dragFileList.size() == 1) {
+		m_dragFileExt = CDragInformation::getDragFileExtension(m_dragFileList.at(0));
+	}
+	else if (m_dragFileList.size() > 1) {
+		m_dragFileExt.clear();
+	}
+	else {
+		return;
+	}
+	
+	m_screen->startDraggingFiles(m_dragFileExt);
+}
+
+bool
+CClient::isReceivedFileSizeValid()
+{
+	return m_expectedFileSize == m_receivedFileData.size();
+}
+
+void
+CClient::sendFileToServer(const char* filename)
+{
+	m_sendFileThread = new CThread(
+		new TMethodJob<CClient>(
+			this, &CClient::sendFileThread,
+			reinterpret_cast<void*>(const_cast<char*>(filename))));
+}
+
+void
+CClient::sendFileThread(void* filename)
+{
+	try {
+		char* name  = reinterpret_cast<char*>(filename);
+		CFileChunker::sendFileChunks(name, m_events, this);
+	}
+	catch (std::runtime_error error) {
+		LOG((CLOG_ERR "failed sending file chunks: %s", error.what()));
+	}
+
+	m_sendFileThread = NULL;
+}
+
+void
+CClient::draggingInfoSending(UInt32 fileCount, CString& fileList, size_t size)
+{
+	m_server->draggingInfoSending(fileCount, fileList.c_str(), size);
 }
