@@ -27,7 +27,8 @@
 // COSXScreenSaver
 //
 
-COSXScreenSaver::COSXScreenSaver(void* eventTarget) :
+COSXScreenSaver::COSXScreenSaver(IEventQueue* events, void* eventTarget) :
+	m_events(events),
 	m_eventTarget(eventTarget),
 	m_enabled(true)
 {
@@ -125,8 +126,8 @@ COSXScreenSaver::processLaunched(ProcessSerialNumber psn)
 		m_screenSaverPSN = psn;
 		LOG((CLOG_DEBUG1 "ScreenSaverEngine launched. Enabled=%d", m_enabled));
 		if (m_enabled) {
-			EVENTQUEUE->addEvent(
-				CEvent(IPrimaryScreen::getScreensaverActivatedEvent(),
+			m_events->addEvent(
+				CEvent(m_events->forIPrimaryScreen().screensaverActivated(),
 					m_eventTarget));
 		}
 	}
@@ -139,8 +140,8 @@ COSXScreenSaver::processTerminated(ProcessSerialNumber psn)
 		m_screenSaverPSN.lowLongOfPSN  == psn.lowLongOfPSN) {
 		LOG((CLOG_DEBUG1 "ScreenSaverEngine terminated. Enabled=%d", m_enabled));
 		if (m_enabled) {
-			EVENTQUEUE->addEvent(
-				CEvent(IPrimaryScreen::getScreensaverDeactivatedEvent(),
+			m_events->addEvent(
+				CEvent(m_events->forIPrimaryScreen().screensaverDeactivated(),
 					m_eventTarget));
 		}
 		
