@@ -38,7 +38,10 @@
 
 static const size_t ModifiersFromXDefaultSize = 32;
 
-CXWindowsKeyState::CXWindowsKeyState(Display* display, bool useXKB) :
+CXWindowsKeyState::CXWindowsKeyState(
+		Display* display, bool useXKB,
+		IEventQueue* events) :
+	CKeyState(events),
 	m_display(display),
 	m_modifierFromX(ModifiersFromXDefaultSize)
 {
@@ -47,8 +50,8 @@ CXWindowsKeyState::CXWindowsKeyState(Display* display, bool useXKB) :
 
 CXWindowsKeyState::CXWindowsKeyState(
 	Display* display, bool useXKB,
-	IEventQueue& eventQueue, CKeyMap& keyMap) :
-	CKeyState(eventQueue, keyMap),
+	IEventQueue* events, CKeyMap& keyMap) :
+	CKeyState(events, keyMap),
 	m_display(display),
 	m_modifierFromX(ModifiersFromXDefaultSize)
 {
