@@ -25,41 +25,11 @@
 // IKeyState
 //
 
-CEvent::Type		IKeyState::s_keyDownEvent   = CEvent::kUnknown;
-CEvent::Type		IKeyState::s_keyUpEvent     = CEvent::kUnknown;
-CEvent::Type		IKeyState::s_keyRepeatEvent = CEvent::kUnknown;
-
-IKeyState::IKeyState() :
-	m_eventQueue(*EVENTQUEUE)
+IKeyState::IKeyState(IEventQueue* events) :
+	m_events(events)
 {
 }
 
-IKeyState::IKeyState(IEventQueue& eventQueue) :
-	m_eventQueue(eventQueue)
-{
-}
-
-CEvent::Type
-IKeyState::getKeyDownEvent(IEventQueue& eventQueue)
-{
-	return eventQueue.registerTypeOnce(s_keyDownEvent,
-							"IKeyState::keyDown");
-}
-
-CEvent::Type
-IKeyState::getKeyUpEvent(IEventQueue& eventQueue)
-{
-	return eventQueue.registerTypeOnce(s_keyUpEvent,
-							"IKeyState::keyUp");
-}
-
-CEvent::Type
-IKeyState::getKeyRepeatEvent(IEventQueue& eventQueue)
-{
-	return eventQueue.registerTypeOnce(s_keyRepeatEvent,
-							"IKeyState::keyRepeat");
-}
-
 //
 // IKeyState::CKeyInfo
 //
