@@ -25,6 +25,7 @@
 #include "CString.h"
 #include "stdset.h"
 #include "IEventQueue.h"
+#include "CEventTypes.h"
 
 //! Key state interface
 /*!
@@ -33,8 +34,7 @@ to synthesize key events.
 */
 class IKeyState : public IInterface {
 public:
-	IKeyState();
-	IKeyState(IEventQueue& eventQueue);
+	IKeyState(IEventQueue* events);
 
 	enum {
 		kNumButtons = 0x200
@@ -164,34 +164,10 @@ public:
 	*/
 	virtual void		pollPressedKeys(KeyButtonSet& pressedKeys) const = 0;
 
-	//! Get key down event type.  Event data is CKeyInfo*, count == 1.
-	CEvent::Type		getKeyDownEvent() { return getKeyDownEvent(m_eventQueue); }
-
-	//! Get key up event type.  Event data is CKeyInfo*, count == 1.
-	CEvent::Type		getKeyUpEvent() { return getKeyUpEvent(m_eventQueue); }
-
-	//! Get key repeat event type.  Event data is CKeyInfo*.
-	CEvent::Type		getKeyRepeatEvent() { return getKeyRepeatEvent(m_eventQueue); }
-
-	//! Get key down event type.  Event data is CKeyInfo*, count == 1.
-	static CEvent::Type	getKeyDownEvent(IEventQueue& eventQueue);
-
-	//! Get key up event type.  Event data is CKeyInfo*, count == 1.
-	static CEvent::Type	getKeyUpEvent(IEventQueue& eventQueue);
-
-	//! Get key repeat event type.  Event data is CKeyInfo*.
-	static CEvent::Type	getKeyRepeatEvent(IEventQueue& eventQueue);
-
 	//@}
 
-protected:
-	IEventQueue& getEventQueue() const { return m_eventQueue; }
-
 private:
-	static CEvent::Type	s_keyDownEvent;
-	static CEvent::Type	s_keyUpEvent;
-	static CEvent::Type	s_keyRepeatEvent;
-	IEventQueue& m_eventQueue;
+	IEventQueue*		m_events;
 };
 
 #endif
